.. @+leo-ver=5-thin
.. @+node:peckj.20130503092808.1682: * @file leo.extensions.rst
.. @@language rest
extensions Package
==================

:mod:`extensions` Package
-------------------------

.. automodule:: leo.extensions
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`asciidoc` Module
----------------------

.. automodule:: leo.extensions.asciidoc
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`colors` Module
--------------------

.. automodule:: leo.extensions.colors
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`patch_11_01` Module
-------------------------

.. automodule:: leo.extensions.patch_11_01
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`sh` Module
----------------

.. automodule:: leo.extensions.sh
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`testExtension` Module
---------------------------

.. automodule:: leo.extensions.testExtension
    :members:
    :undoc-members:
    :show-inheritance:

.. @-leo
